@@ -1,6 +1,6 @@
 package Statocles::Command;
 # ABSTRACT: The statocles command-line interface
-$Statocles::Command::VERSION = '0.056';
+$Statocles::Command::VERSION = '0.057';
 use Statocles::Base 'Class';
 use Scalar::Util qw( blessed );
 use Getopt::Long qw( GetOptionsFromArray :config pass_through bundling no_auto_abbrev );
@@ -58,10 +58,10 @@ sub main {
     if ( $@ ) {
         if ( blessed $@ && $@->isa( 'Beam::Wire::Exception::Config' ) ) {
             my $remedy;
-            if ( $@ =~ /found character that cannot start any token/ ) {
+            if ( $@ =~ /found character that cannot start any token/ || $@ =~ /YAML_PARSE_ERR_NONSPACE_INDENTATION/ ) {
                 $remedy = "Check that you are not using tabs for indentation. ";
             }
-            elsif ( $@ =~ /did not find expected key/ ) {
+            elsif ( $@ =~ /did not find expected key/ || $@ =~ /YAML_PARSE_ERR_INCONSISTENT_INDENTATION/ ) {
                 $remedy = "Check your indentation. ";
             }
 
@@ -591,7 +591,7 @@ Statocles::Command - The statocles command-line interface
 
 =head1 VERSION
 
-version 0.056
+version 0.057
 
 =head1 SYNOPSIS
 
